@@ -10,11 +10,12 @@ __metaclass__ = type
 
 
 import pytest
-
-from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import MagicMock, patch
+from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import (
+    MagicMock,
+    patch,
+)
 
 from ansible_collections.community.dns.plugins.module_utils import resolver
-
 from ansible_collections.community.dns.plugins.module_utils.resolver import (
     ResolveDirectlyFromNameServers,
     ResolverError,
@@ -22,10 +23,10 @@ from ansible_collections.community.dns.plugins.module_utils.resolver import (
 )
 
 from .resolver_helper import (
-    mock_resolver,
-    mock_query_udp,
     create_mock_answer,
     create_mock_response,
+    mock_query_udp,
+    mock_resolver,
 )
 
 # We need dnspython
@@ -52,14 +53,14 @@ def test_assert_requirements_present():
             assert_requirements_present(module)
 
         assert 'dnspython' in exc.value.args[0]['msg']
-        assert 'asdf' == exc.value.args[0]['exception']
+        assert exc.value.args[0]['exception'] == 'asdf'
 
     finally:
         resolver.DNSPYTHON_IMPORTERROR = orig_importerror
 
 
 def test_lookup_ns_names():
-    resolver = mock_resolver(['1.1.1.1'], {})
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {})
     udp_sequence = [
         {
             'query_target': dns.name.from_unicode(u'example.com'),
@@ -93,28 +94,28 @@ def test_lookup_ns_names():
             )]),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
-                resolver = ResolveDirectlyFromNameServers(always_ask_default_resolver=False)
+                resolver_instance = ResolveDirectlyFromNameServers(always_ask_default_resolver=False)
                 # Use default resolver
-                ns, cname = resolver._lookup_ns_names(dns.name.from_unicode(u'example.com'))
+                ns, cname = resolver_instance._lookup_ns_names(dns.name.from_unicode(u'example.com'))
                 assert ns == ['ns.example.com.', 'ns.example.org.']
                 assert cname is None
                 # Provide nameserver IPs
-                ns, cname = resolver._lookup_ns_names(dns.name.from_unicode(u'example.com'), nameserver_ips=['3.3.3.3', '1.1.1.1'])
+                ns, cname = resolver_instance._lookup_ns_names(dns.name.from_unicode(u'example.com'), nameserver_ips=['3.3.3.3', '1.1.1.1'])
                 assert ns == ['ns.example.com.']
                 assert cname == dns.name.from_unicode(u'foo.bar.')
                 # Provide empty nameserver list
                 with pytest.raises(ResolverError) as exc:
-                    resolver._lookup_ns_names(dns.name.from_unicode(u'example.com'), nameservers=[])
+                    resolver_instance._lookup_ns_names(dns.name.from_unicode(u'example.com'), nameservers=[])
                 assert exc.value.args[0] == 'Have neither nameservers nor nameserver IPs'
 
 
 def test_resolver():
     fake_query = MagicMock()
     fake_query.question = 'Doctor Who?'
-    resolver = mock_resolver(['1.1.1.1'], {
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {
         ('1.1.1.1', ): [
             {
                 'target': 'ns.example.com',
@@ -265,13 +266,13 @@ def test_resolver():
             )]),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
-                resolver = ResolveDirectlyFromNameServers()
-                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['1:2::3', '2:3::4', '3.3.3.3']
+                resolver_instance = ResolveDirectlyFromNameServers()
+                assert resolver_instance.resolve_nameservers('example.com', resolve_addresses=True) == ['1:2::3', '2:3::4', '3.3.3.3']
                 # www.example.com is a CNAME for example.org
-                rrset_dict = resolver.resolve('www.example.com')
+                rrset_dict = resolver_instance.resolve('www.example.com')
                 assert sorted(rrset_dict.keys()) == ['ns.example.com', 'ns.example.org']
                 rrset = rrset_dict['ns.example.com']
                 assert len(rrset) == 1
@@ -284,16 +285,16 @@ def test_resolver():
                 assert rrset.rdtype == dns.rdatatype.A
                 assert rrset[0].to_text() == u'1.2.3.5'
                 # The following results should be cached:
-                assert resolver.resolve_nameservers('com', resolve_addresses=True) == ['2.2.2.2']
-                assert resolver.resolve_nameservers('org') == ['ns.org']
-                assert resolver.resolve_nameservers('example.com') == ['ns.example.com']
-                assert resolver.resolve_nameservers('example.org') == ['ns.example.com', 'ns.example.org']
+                assert resolver_instance.resolve_nameservers('com', resolve_addresses=True) == ['2.2.2.2']
+                assert resolver_instance.resolve_nameservers('org') == ['ns.org']
+                assert resolver_instance.resolve_nameservers('example.com') == ['ns.example.com']
+                assert resolver_instance.resolve_nameservers('example.org') == ['ns.example.com', 'ns.example.org']
 
 
 def test_timeout_handling():
     fake_query = MagicMock()
     fake_query.question = 'Doctor Who?'
-    resolver = mock_resolver(['1.1.1.1'], {
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {
         ('1.1.1.1', ): [
             {
                 'target': 'ns.example.com',
@@ -390,20 +391,20 @@ def test_timeout_handling():
             )]),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
-                resolver = ResolveDirectlyFromNameServers()
-                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
+                resolver_instance = ResolveDirectlyFromNameServers()
+                assert resolver_instance.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
                 # The following results should be cached:
-                assert resolver.resolve_nameservers('com') == ['ns.com']
-                assert resolver.resolve_nameservers('com', resolve_addresses=True) == ['2.2.2.2']
-                assert resolver.resolve_nameservers('example.com') == ['ns.example.com']
-                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
+                assert resolver_instance.resolve_nameservers('com') == ['ns.com']
+                assert resolver_instance.resolve_nameservers('com', resolve_addresses=True) == ['2.2.2.2']
+                assert resolver_instance.resolve_nameservers('example.com') == ['ns.example.com']
+                assert resolver_instance.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
 
 
 def test_timeout_failure():
-    resolver = mock_resolver(['1.1.1.1'], {})
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {})
     udp_sequence = [
         {
             'query_target': dns.name.from_unicode(u'com'),
@@ -442,17 +443,17 @@ def test_timeout_failure():
             'raise': dns.exception.Timeout(timeout=4),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                 with pytest.raises(dns.exception.Timeout) as exc:
-                    resolver = ResolveDirectlyFromNameServers()
-                    resolver.resolve_nameservers('example.com')
+                    resolver_instance = ResolveDirectlyFromNameServers()
+                    resolver_instance.resolve_nameservers('example.com')
                 assert exc.value.kwargs['timeout'] == 4
 
 
-def test_error_nxdomain():
-    resolver = mock_resolver(['1.1.1.1'], {})
+def test_error_nameserver_nxdomain_none():
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {})
     udp_sequence = [
         {
             'query_target': dns.name.from_unicode(u'com'),
@@ -463,18 +464,225 @@ def test_error_nxdomain():
             },
             'result': create_mock_response(dns.rcode.NXDOMAIN),
         },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NXDOMAIN),
+        },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver_instance = ResolveDirectlyFromNameServers()
+                assert resolver_instance.resolve_nameservers('example.com') == []
+
+
+def test_error_nameserver_nxdomain_partial_first():
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {})
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NXDOMAIN),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver_instance = ResolveDirectlyFromNameServers()
+                assert resolver_instance.resolve_nameservers('example.com') == ['ns.com']
+
+
+def test_error_nameserver_nxdomain_partial_second():
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {})
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NXDOMAIN),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver_instance = ResolveDirectlyFromNameServers()
+                assert resolver_instance.resolve_nameservers('example.com') == ['ns.com']
+
+
+def test_error_nxdomain_ok():
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {
+        ('1.1.1.1', ): [
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
+                )),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.AAAA, '1:2::3'),
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.AAAA, '2:3::4'),
+                )),
+            },
+        ],
+        ('1:2::3', '2:3::4', '3.3.3.3'): [
+            {
+                'target': dns.name.from_unicode(u'example.com'),
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.NXDOMAIN),
+            },
+        ],
+    })
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NXDOMAIN),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver_instance = ResolveDirectlyFromNameServers()
+                rrset_dict = resolver_instance.resolve('example.com', nxdomain_is_empty=True)
+                print(rrset_dict)
+                assert sorted(rrset_dict.keys()) == ['ns.com']
+                assert rrset_dict['ns.com'] == []
+
+
+def test_error_nxdomain_fail():
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {
+        ('1.1.1.1', ): [
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
+                )),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.AAAA, '1:2::3'),
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.AAAA, '2:3::4'),
+                )),
+            },
+        ],
+        ('1:2::3', '2:3::4', '3.3.3.3'): [
+            {
+                'target': dns.name.from_unicode(u'example.com'),
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.NXDOMAIN),
+            },
+        ],
+    })
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NXDOMAIN),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver_instance = ResolveDirectlyFromNameServers()
                 with pytest.raises(dns.resolver.NXDOMAIN) as exc:
-                    resolver = ResolveDirectlyFromNameServers()
-                    resolver.resolve_nameservers('example.com')
-                assert exc.value.kwargs['qnames'] == [dns.name.from_unicode(u'com')]
+                    resolver_instance.resolve('example.com', nxdomain_is_empty=False)
+                print(exc.value.args[0])
+                assert exc.value.args[0] == 'The DNS query name does not exist: example.com.'
 
 
 def test_error_servfail():
-    resolver = mock_resolver(['1.1.1.1'], {})
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {})
     udp_sequence = [
         {
             'query_target': dns.name.from_unicode(u'com'),
@@ -486,17 +694,17 @@ def test_error_servfail():
             'result': create_mock_response(dns.rcode.SERVFAIL),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                 with pytest.raises(ResolverError) as exc:
-                    resolver = ResolveDirectlyFromNameServers()
-                    resolver.resolve_nameservers('example.com')
+                    resolver_instance = ResolveDirectlyFromNameServers()
+                    resolver_instance.resolve_nameservers('example.com')
                 assert exc.value.args[0] == 'Error SERVFAIL while querying 1.1.1.1 with query get NS for "com."'
 
 
 def test_error_servfail_retry_success():
-    resolver = mock_resolver(['1.1.1.1'], {})
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {})
     udp_sequence = [
         {
             'query_target': dns.name.from_unicode(u'com'),
@@ -530,15 +738,15 @@ def test_error_servfail_retry_success():
             )]),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
-                resolver = ResolveDirectlyFromNameServers(servfail_retries=2)
-                assert resolver.resolve_nameservers('com') == ['ns.com']
+                resolver_instance = ResolveDirectlyFromNameServers(servfail_retries=2)
+                assert resolver_instance.resolve_nameservers('com') == ['ns.com']
 
 
 def test_error_servfail_retry_fail():
-    resolver = mock_resolver(['1.1.1.1'], {})
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {})
     udp_sequence = [
         {
             'query_target': dns.name.from_unicode(u'com'),
@@ -568,19 +776,19 @@ def test_error_servfail_retry_fail():
             'result': create_mock_response(dns.rcode.SERVFAIL),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
                 with pytest.raises(ResolverError) as exc:
-                    resolver = ResolveDirectlyFromNameServers(servfail_retries=2)
-                    resolver.resolve_nameservers('example.com')
+                    resolver_instance = ResolveDirectlyFromNameServers(servfail_retries=2)
+                    resolver_instance.resolve_nameservers('example.com')
                 assert exc.value.args[0] == 'Error SERVFAIL while querying 1.1.1.1 with query get NS for "com."'
 
 
 def test_servfail_handling():
     fake_query = MagicMock()
     fake_query.question = 'Doctor Who?'
-    resolver = mock_resolver(['1.1.1.1'], {
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {
         ('1.1.1.1', ): [
             {
                 'target': 'ns.example.com',
@@ -668,22 +876,22 @@ def test_servfail_handling():
             )]),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
-                resolver = ResolveDirectlyFromNameServers(servfail_retries=2)
-                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
+                resolver_instance = ResolveDirectlyFromNameServers(servfail_retries=2)
+                assert resolver_instance.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
                 # The following results should be cached:
-                assert resolver.resolve_nameservers('com') == ['ns.com']
-                assert resolver.resolve_nameservers('com', resolve_addresses=True) == ['2.2.2.2']
-                assert resolver.resolve_nameservers('example.com') == ['ns.example.com']
-                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
+                assert resolver_instance.resolve_nameservers('com') == ['ns.com']
+                assert resolver_instance.resolve_nameservers('com', resolve_addresses=True) == ['2.2.2.2']
+                assert resolver_instance.resolve_nameservers('example.com') == ['ns.example.com']
+                assert resolver_instance.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
 
 
 def test_servfail_failing():
     fake_query = MagicMock()
     fake_query.question = 'Doctor Who?'
-    resolver = mock_resolver(['1.1.1.1'], {
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {
         ('1.1.1.1', ): [
             {
                 'target': 'ns.example.com',
@@ -783,22 +991,22 @@ def test_servfail_failing():
             )]),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
-                resolver = ResolveDirectlyFromNameServers(servfail_retries=2)
-                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
+                resolver_instance = ResolveDirectlyFromNameServers(servfail_retries=2)
+                assert resolver_instance.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
                 # The following results should be cached:
-                assert resolver.resolve_nameservers('com') == ['ns.com']
+                assert resolver_instance.resolve_nameservers('com') == ['ns.com']
                 with pytest.raises(ResolverError) as exc:
-                    resolver.resolve_nameservers('com', resolve_addresses=True)
+                    resolver_instance.resolve_nameservers('com', resolve_addresses=True)
                 assert exc.value.args[0] == "Error SERVFAIL while querying ['1.1.1.1']"
 
 
 def test_no_response():
     fake_query = MagicMock()
     fake_query.question = 'Doctor Who?'
-    resolver = mock_resolver(['1.1.1.1'], {
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {
         ('1.1.1.1', ): [
             {
                 'target': 'ns.example.com',
@@ -878,21 +1086,21 @@ def test_no_response():
             )]),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
-                resolver = ResolveDirectlyFromNameServers()
-                rrset_dict = resolver.resolve('example.com')
+                resolver_instance = ResolveDirectlyFromNameServers()
+                rrset_dict = resolver_instance.resolve('example.com')
                 assert sorted(rrset_dict.keys()) == ['ns.example.com', 'ns2.example.com']
                 assert rrset_dict['ns.example.com'] is None
                 assert rrset_dict['ns2.example.com'] is None
                 # Verify nameserver IPs
-                assert resolver.resolve_nameservers('example.com') == ['ns.example.com', 'ns2.example.com']
-                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3', '4.4.4.4', '5.5.5.5']
+                assert resolver_instance.resolve_nameservers('example.com') == ['ns.example.com', 'ns2.example.com']
+                assert resolver_instance.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3', '4.4.4.4', '5.5.5.5']
 
 
 def test_cname_loop():
-    resolver = mock_resolver(['1.1.1.1'], {
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {
         ('1.1.1.1', ): [
             {
                 'target': 'ns.com',
@@ -1007,19 +1215,19 @@ def test_cname_loop():
             )]),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
-                resolver = ResolveDirectlyFromNameServers()
+                resolver_instance = ResolveDirectlyFromNameServers()
                 with pytest.raises(ResolverError) as exc:
-                    resolver.resolve('www.example.com')
+                    resolver_instance.resolve('www.example.com')
                 assert exc.value.args[0] == 'Found CNAME loop starting at www.example.com'
 
 
 def test_resolver_non_default():
     fake_query = MagicMock()
     fake_query.question = 'Doctor Who?'
-    resolver = mock_resolver(['1.1.1.1'], {
+    mock_resolver_instance = mock_resolver(['1.1.1.1'], {
         ('1.1.1.1', ): [
             {
                 'target': 'ns.com',
@@ -1181,13 +1389,13 @@ def test_resolver_non_default():
             )]),
         },
     ]
-    with patch('dns.resolver.get_default_resolver', resolver):
-        with patch('dns.resolver.Resolver', resolver):
+    with patch('dns.resolver.get_default_resolver', mock_resolver_instance):
+        with patch('dns.resolver.Resolver', mock_resolver_instance):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
-                resolver = ResolveDirectlyFromNameServers(always_ask_default_resolver=False)
-                assert resolver.resolve_nameservers('example.com') == ['ns.example.com']
+                resolver_instance = ResolveDirectlyFromNameServers(always_ask_default_resolver=False)
+                assert resolver_instance.resolve_nameservers('example.com') == ['ns.example.com']
                 # www.example.com is a CNAME for example.org
-                rrset_dict = resolver.resolve('www.example.com')
+                rrset_dict = resolver_instance.resolve('www.example.com')
                 assert sorted(rrset_dict.keys()) == ['ns.example.com', 'ns.example.org']
                 rrset = rrset_dict['ns.example.com']
                 assert len(rrset) == 1
@@ -1200,8 +1408,8 @@ def test_resolver_non_default():
                 assert rrset.rdtype == dns.rdatatype.A
                 assert rrset[0].to_text() == u'1.2.3.4'
                 # The following results should be cached:
-                assert resolver.resolve_nameservers('com') == ['ns.com']
-                print(resolver.resolve_nameservers('example.com', resolve_addresses=True))
-                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
-                print(resolver.resolve_nameservers('example.org', resolve_addresses=True))
-                assert resolver.resolve_nameservers('example.org', resolve_addresses=True) == ['3.3.3.3', '4.4.4.4']
+                assert resolver_instance.resolve_nameservers('com') == ['ns.com']
+                print(resolver_instance.resolve_nameservers('example.com', resolve_addresses=True))
+                assert resolver_instance.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
+                print(resolver_instance.resolve_nameservers('example.org', resolve_addresses=True))
+                assert resolver_instance.resolve_nameservers('example.org', resolve_addresses=True) == ['3.3.3.3', '4.4.4.4']
