@@ -3,13 +3,14 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import annotations
+
 import lmdb
 
 map_size = 1024 * 100
 env = lmdb.open("./jp.mdb", map_size=map_size)
 with env.begin(write=True) as txn:
-    txn.put("fr".encode(), "France".encode())
-    txn.put("nl".encode(), "Netherlands".encode())
-    txn.put("es".encode(), "Spain".encode())
-    txn.put("be".encode(), "Belgium".encode())
-    txn.put("lu".encode(), "Luxembourg".encode())
+    txn.put(b"fr", b"France")
+    txn.put(b"nl", b"Netherlands")
+    txn.put(b"es", b"Spain")
+    txn.put(b"be", b"Belgium")
+    txn.put(b"lu", b"Luxembourg")
