@@ -27,6 +27,8 @@ port = "25:465"
 if len(sys.argv) > 1:
     port = sys.argv[1]
 ports = port.split(":")
+port1: int
+port2: int | None
 if len(ports) > 1:
     port1, port2 = int(ports[0]), int(ports[1])
 else:
@@ -46,7 +48,7 @@ if len(sys.argv) > 3:
 ssl_ctx = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH)
 
 if HAS_TLS and ssl_ctx is not None:
-    print("Using %s and %s" % (certfile, keyfile))
+    print(f"Using {certfile} and {keyfile}")
     ssl_ctx.load_cert_chain(certfile=certfile, keyfile=keyfile)
 
     print("Start SMTP server on port", port1)
@@ -58,6 +60,6 @@ else:
     print("Start SMTP server on port", port1)
     smtp_server1 = smtpd.DebuggingServer(("127.0.0.1", port1), None)  # pylint: disable=used-before-assignment
     if port2:
-        print("WARNING: TLS is NOT supported on this system, not listening on port %s." % port2)
+        print(f"WARNING: TLS is NOT supported on this system, not listening on port {port2}.")
 
 asyncore.loop()
