@@ -8,13 +8,12 @@ import json
 from unittest.mock import MagicMock
 
 import pytest
-
 from ansible.module_utils.common.dict_transformations import dict_merge
+
 from ansible_collections.community.general.plugins.module_utils.net_tools.pritunl import (
     api,
 )
 
-
 # Pritunl Mocks
 
 PRITUNL_ORGS = [
@@ -441,7 +440,7 @@ class TestPritunlApi:
 
         for org in response:
             if org["id"] == org_id:
-                org["user_count"] == org_user_count
+                assert org["user_count"] == org_user_count
 
     @pytest.mark.parametrize(
         "org_filters,org_expected",
