@@ -7,31 +7,15 @@
 from __future__ import annotations
 
 import os
-from unittest.mock import patch, Mock
+from unittest.mock import Mock, patch
 
+from ansible.module_utils.basic import AnsibleModule  # noqa: F401 # pylint: disable=unused-import
 from ansible_collections.community.internal_test_tools.tests.unit.plugins.modules.utils import (
     ModuleTestCase,
     set_module_args,
 )
-from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.general.plugins.modules.java_keystore import JavaKeystore
 
-
-module_argument_spec = dict(
-    name=dict(type="str", required=True),
-    dest=dict(type="path", required=True),
-    certificate=dict(type="str", no_log=True),
-    certificate_path=dict(type="path"),
-    private_key=dict(type="str", no_log=True),
-    private_key_path=dict(type="path", no_log=False),
-    private_key_passphrase=dict(type="str", no_log=True),
-    password=dict(type="str", required=True, no_log=True),
-    ssl_backend=dict(type="str", default="openssl", choices=["openssl", "cryptography"]),
-    keystore_type=dict(type="str", choices=["jks", "pkcs12"]),
-    force=dict(type="bool", default=False),
-)
-module_supports_check_mode = True
-module_choose_between = (["certificate", "certificate_path"], ["private_key", "private_key_path"])
+from ansible_collections.community.general.plugins.modules.java_keystore import JavaKeystore, create_module
 
 
 class TestCreateJavaKeystore(ModuleTestCase):
@@ -96,12 +80,7 @@ class TestCreateJavaKeystore(ModuleTestCase):
                 password="changeit",
             )
         ):
-            module = AnsibleModule(
-                argument_spec=module_argument_spec,
-                supports_check_mode=module_supports_check_mode,
-                mutually_exclusive=module_choose_between,
-                required_one_of=module_choose_between,
-            )
+            module = create_module()
 
         with patch("os.remove", return_value=True):
             self.create_path.side_effect = ["/tmp/tmpgrzm2ah7"]
@@ -139,12 +118,7 @@ class TestCreateJavaKeystore(ModuleTestCase):
                 password="changeit",
             )
         ):
-            module = AnsibleModule(
-                argument_spec=module_argument_spec,
-                supports_check_mode=module_supports_check_mode,
-                mutually_exclusive=module_choose_between,
-                required_one_of=module_choose_between,
-            )
+            module = create_module()
 
         module.exit_json = Mock()
         module.fail_json = Mock()
@@ -189,12 +163,7 @@ class TestCreateJavaKeystore(ModuleTestCase):
                 password="changeit",
             )
         ):
-            module = AnsibleModule(
-                argument_spec=module_argument_spec,
-                supports_check_mode=module_supports_check_mode,
-                mutually_exclusive=module_choose_between,
-                required_one_of=module_choose_between,
-            )
+            module = create_module()
 
         module.exit_json = Mock()
         module.fail_json = Mock()
@@ -237,12 +206,7 @@ class TestCreateJavaKeystore(ModuleTestCase):
                 password="changeit",
             )
         ):
-            module = AnsibleModule(
-                argument_spec=module_argument_spec,
-                supports_check_mode=module_supports_check_mode,
-                mutually_exclusive=module_choose_between,
-                required_one_of=module_choose_between,
-            )
+            module = create_module()
 
         module.exit_json = Mock()
         module.fail_json = Mock()
@@ -315,12 +279,7 @@ class TestCertChanged(ModuleTestCase):
                 password="changeit",
             )
         ):
-            module = AnsibleModule(
-                argument_spec=module_argument_spec,
-                supports_check_mode=module_supports_check_mode,
-                mutually_exclusive=module_choose_between,
-                required_one_of=module_choose_between,
-            )
+            module = create_module()
 
         with patch("os.remove", return_value=True):
             self.create_file.side_effect = ["/tmp/placeholder", ""]
@@ -341,12 +300,7 @@ class TestCertChanged(ModuleTestCase):
                 password="changeit",
             )
         ):
-            module = AnsibleModule(
-                argument_spec=module_argument_spec,
-                supports_check_mode=module_supports_check_mode,
-                mutually_exclusive=module_choose_between,
-                required_one_of=module_choose_between,
-            )
+            module = create_module()
 
         with patch("os.remove", return_value=True):
             self.create_file.side_effect = ["/tmp/placeholder", ""]
@@ -367,12 +321,7 @@ class TestCertChanged(ModuleTestCase):
                 password="changeit",
             )
         ):
-            module = AnsibleModule(
-                argument_spec=module_argument_spec,
-                supports_check_mode=module_supports_check_mode,
-                mutually_exclusive=module_choose_between,
-                required_one_of=module_choose_between,
-            )
+            module = create_module()
 
         with patch("os.remove", return_value=True):
             self.create_file.side_effect = ["/tmp/placeholder", ""]
@@ -395,12 +344,7 @@ class TestCertChanged(ModuleTestCase):
                 password="changeit",
             )
         ):
-            module = AnsibleModule(
-                argument_spec=module_argument_spec,
-                supports_check_mode=module_supports_check_mode,
-                mutually_exclusive=module_choose_between,
-                required_one_of=module_choose_between,
-            )
+            module = create_module()
 
         with patch("os.remove", return_value=True):
             self.create_file.side_effect = ["/tmp/placeholder", ""]
@@ -423,12 +367,7 @@ class TestCertChanged(ModuleTestCase):
                 password="changeit",
             )
         ):
-            module = AnsibleModule(
-                argument_spec=module_argument_spec,
-                supports_check_mode=module_supports_check_mode,
-                mutually_exclusive=module_choose_between,
-                required_one_of=module_choose_between,
-            )
+            module = create_module()
 
         module.exit_json = Mock()
         module.fail_json = Mock()
@@ -457,12 +396,7 @@ class TestCertChanged(ModuleTestCase):
                 password="changeit",
             )
         ):
-            module = AnsibleModule(
-                argument_spec=module_argument_spec,
-                supports_check_mode=module_supports_check_mode,
-                mutually_exclusive=module_choose_between,
-                required_one_of=module_choose_between,
-            )
+            module = create_module()
 
         module.exit_json = Mock()
         module.fail_json = Mock(return_value=True)
